@@ -1,16 +1,16 @@
-from typing import TypeVar, Optional
+from typing import TypeVar, Optional, Type, List, Any
 
 T = TypeVar("T")
 
 
-def _optional(payload, key, class_type: T) -> Optional[T]:
+def _optional(payload: dict, key: str, class_type: Type[T]) -> Optional[T]:
     if payload.get(key):
         return class_type(payload[key])
     else:
         return None
 
 
-def _transform(url: str, local_variables):
+def _transform(url: str, local_variables: dict) -> str:
     local_variables.pop("self", None)
 
     for key, value in local_variables.items():
@@ -26,7 +26,50 @@ def _transform(url: str, local_variables):
     return url
 
 
+class Enterprise:
+    id: int
+    slug: str
+    name: str
+    node_id: str
+    avatar_url: str
+    description: Optional[str]
+    website_url: Optional[str]
+    html_url: str
+    created_at: str
+    updated_at: str
+
+    def __init__(self, payload: dict):
+        self.id = payload.get("id")
+        self.slug = payload.get("slug")
+        self.name = payload.get("name")
+        self.node_id = payload.get("node_id")
+        self.avatar_url = payload.get("avatar_url")
+        self.description = payload.get("description")
+        self.website_url = payload.get("website_url")
+        self.html_url = payload.get("html_url")
+        self.created_at = payload.get("created_at")
+        self.updated_at = payload.get("updated_at")
+
+
 class User:
+    name: Optional[str]
+    login: str
+    email: Optional[str]
+    id: int
+    node_id: Optional[str]
+    avatar_url: str
+    gravatar_id: str
+    url: str
+    html_url: str
+    followers_url: str
+    subscriptions_url: str
+    organization_url: str
+    repos_url: str
+    organizations_url: str
+    received_events_url: str
+    type: str
+    site_admin: bool
+
     def __init__(self, payload: dict):
         self._payload = payload
         self.name = payload.get("name")
@@ -47,20 +90,26 @@ class User:
         self.type = payload.get("type")
         self.site_admin = payload.get("site_admin")
 
-    def following_url(self, other_user: str = None):
+    def following_url(self, other_user: str = None) -> str:
         return _transform(self._payload["following_url"], locals())
 
-    def gists_url(self, gist_id: str = None):
+    def gists_url(self, gist_id: str = None) -> str:
         return _transform(self._payload["gists_url"], locals())
 
-    def starred_url(self, owner: str = None, repo: str = None):
+    def starred_url(self, owner: str = None, repo: str = None) -> str:
         return _transform(self._payload["starred_url"], locals())
 
-    def events_url(self, privacy: str = None):
+    def events_url(self, privacy: str = None) -> str:
         return _transform(self._payload["events_url"], locals())
 
 
 class ShortRepository:
+    id: int
+    node_id: str
+    name: str
+    full_name: str
+    private: bool
+
     def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
@@ -69,7 +118,116 @@ class ShortRepository:
         self.private = payload.get("private")
 
 
+class RawDict(dict):
+    def __init__(self, payload: dict):
+        super().__init__(payload)
+
+
+class Permissions:
+    metadata: str
+    contents: str
+    issues: str
+    administration: str
+    statuses: str
+    repository_projects: str
+    members: str
+    repository_hooks: str
+    pull_requests: str
+    pull: Optional[str]
+    push: Optional[str]
+    admin: Optional[str]
+    pages: str
+    deployments: str
+    checks: str
+    vulnerability_alerts: str
+    organization_administration: str
+    organization_hooks: str
+    organization_plan: str
+    organization_projects: str
+    organization_user_blocking: str
+    team_discussions: str
+
+    def __init__(self, payload: dict):
+        self.metadata = payload.get("metadata")
+        self.contents = payload.get("contents")
+        self.issues = payload.get("issues")
+        self.administration = payload.get("administration")
+        self.statuses = payload.get("statuses")
+        self.repository_projects = payload.get("repository_projects")
+        self.members = payload.get("members")
+        self.repository_hooks = payload.get("repository_hooks")
+        self.pull_requests = payload.get("pull_requests")
+        self.pull = payload.get("pull")
+        self.push = payload.get("push")
+        self.admin = payload.get("admin")
+        self.pages = payload.get("pages")
+        self.deployments = payload.get("deployments")
+        self.checks = payload.get("checks")
+        self.vulnerability_alerts = payload.get("vulnerability_alerts")
+        self.organization_administration = payload.get("organization_administration")
+        self.organization_hooks = payload.get("organization_hooks")
+        self.organization_plan = payload.get("organization_plan")
+        self.organization_projects = payload.get("organization_projects")
+        self.organization_user_blocking = payload.get("organization_user_blocking")
+        self.team_discussions = payload.get("team_discussions")
+
+
 class Repository:
+    id: int
+    node_id: str
+    name: str
+    full_name: str
+    private: bool
+    owner: User
+    html_url: str
+    description: str
+    fork: bool
+    url: str
+    forks_url: str
+    teams_url: str
+    hooks_url: str
+    events_url: str
+    tags_url: str
+    languages_url: str
+    stargazers_url: str
+    contributors_url: str
+    subscribers_url: str
+    subscription_url: str
+    merges_url: str
+    downloads_url: str
+    deployments_url: str
+    created_at: str
+    updated_at: str
+    pushed_at: str
+    git_url: str
+    ssh_url: str
+    clone_url: str
+    svn_url: str
+    homepage: Optional[str]
+    size: int
+    stargazers_count: int
+    watchers_count: int
+    language: Optional[str]
+    has_issues: bool
+    has_projects: bool
+    has_downloads: bool
+    has_wiki: bool
+    has_pages: bool
+    forks_count: int
+    mirror_url: Optional[str]
+    archived: bool
+    disabled: bool
+    open_issues_count: int
+    license: Optional[str]
+    forks: int
+    open_issues: int
+    watchers: int
+    default_branch: str
+    stargazers: Optional[int]
+    public: Optional[bool]
+    master_branch: Optional[str]
+    permissions: Optional[Permissions]
+
     def __init__(self, payload: dict):
         self._payload = payload
         self.id = payload.get("id")
@@ -127,67 +285,67 @@ class Repository:
         self.master_branch = payload.get("master_branch")
         self.permissions = _optional(payload, "permissions", Permissions)
 
-    def keys_url(self, key_id: str = None):
+    def keys_url(self, key_id: str = None) -> str:
         return _transform(self._payload["keys_url"], locals())
 
-    def collaborators_url(self, collaborator: str = None):
+    def collaborators_url(self, collaborator: str = None) -> str:
         return _transform(self._payload["collaborators_url"], locals())
 
-    def issue_events_url(self, number: int = None):
+    def issue_events_url(self, number: int = None) -> str:
         return _transform(self._payload["issue_events_url"], locals())
 
-    def assignees_url(self, user: str = None):
+    def assignees_url(self, user: str = None) -> str:
         return _transform(self._payload["assignees_url"], locals())
 
-    def branches_url(self, branch: str = None):
+    def branches_url(self, branch: str = None) -> str:
         return _transform(self._payload["branches_url"], locals())
 
-    def blobs_url(self, sha: str = None):
+    def blobs_url(self, sha: str = None) -> str:
         return _transform(self._payload["blobs_url"], locals())
 
-    def git_tags_url(self, sha: str = None):
+    def git_tags_url(self, sha: str = None) -> str:
         return _transform(self._payload["git_tags_url"], locals())
 
-    def git_refs_url(self, sha: str = None):
+    def git_refs_url(self, sha: str = None) -> str:
         return _transform(self._payload["git_refs_url"], locals())
 
-    def trees_url(self, sha: str = None):
+    def trees_url(self, sha: str = None) -> str:
         return _transform(self._payload["trees_url"], locals())
 
-    def statuses_url(self, sha: str):
+    def statuses_url(self, sha: str) -> str:
         return _transform(self._payload["statuses_url"], locals())
 
-    def commits_url(self, sha: str = None):
+    def commits_url(self, sha: str = None) -> str:
         return _transform(self._payload["commits_url"], locals())
 
-    def git_commits_url(self, sha=None):
+    def git_commits_url(self, sha=None) -> str:
         return _transform(self._payload["git_commits_url"], locals())
 
-    def comments_url(self, number: int = None):
+    def comments_url(self, number: int = None) -> str:
         return _transform(self._payload["comments_url"], locals())
 
-    def issue_comment_url(self, number: int = None):
+    def issue_comment_url(self, number: int = None) -> str:
         return _transform(self._payload["issue_comment_url"], locals())
 
-    def contents_url(self, path: str):
+    def contents_url(self, path: str) -> str:
         return _transform(self._payload["contents_url"].replace("+", ""), locals())
 
-    def compare_url(self, base: str, head: str):
+    def compare_url(self, base: str, head: str) -> str:
         return _transform(self._payload["compare_url"], locals())
 
-    def archive_url(self, archive_format: str, ref: str = None):
+    def archive_url(self, archive_format: str, ref: str = None) -> str:
         return _transform(self._payload["archive_url"], locals())
 
-    def issues_url(self, number: str = None):
+    def issues_url(self, number: str = None) -> str:
         return _transform(self._payload["issues_url"], locals())
 
-    def pulls_url(self, number: str = None):
+    def pulls_url(self, number: str = None) -> str:
         return _transform(self._payload["pulls_url"], locals())
 
-    def milestones_url(self, number: str = None):
+    def milestones_url(self, number: str = None) -> str:
         return _transform(self._payload["milestones_url"], locals())
 
-    def notifications_url(self, params: str = None):
+    def notifications_url(self, params: str = None) -> str:
         if params is not None:
             if not params.startswith("?"):
                 raise AttributeError("Params must be a query string starting with ?")
@@ -196,15 +354,27 @@ class Repository:
             "{?since,all,participating}", replace_with
         )
 
-    def labels_url(self, name: str = None):
+    def labels_url(self, name: str = None) -> str:
         return _transform(self._payload["labels_url"], locals())
 
-    def releases_url(self, id: str = None):
+    def releases_url(self, id: str = None) -> str:
         return _transform(self._payload["releases_url"], locals())
 
 
 class Organization:
-    def __init__(self, payload):
+    login: str
+    id: int
+    node_id: str
+    url: str
+    repos_url: str
+    events_url: str
+    hooks_url: str
+    issues_url: str
+    public_members_url: str
+    avatar_url: str
+    description: str
+
+    def __init__(self, payload: dict):
         self._payload = payload
         self.login = payload.get("login")
         self.id = payload.get("id")
@@ -218,15 +388,35 @@ class Organization:
         self.avatar_url = payload.get("avatar_url")
         self.description = payload.get("description")
 
-    def members_url(self, member: str = None):
+    def members_url(self, member: str = None) -> str:
         return _transform(self._payload["members_url"], locals())
 
-    def public_members_url(self, member: str = None):
+    def public_members_url(self, member: str = None) -> str:
         return _transform(self._payload["public_members_url"], locals())
 
 
 class Comment:
-    def __init__(self, payload):
+    url: str
+    html_url: str
+    issue_url: Optional[str]
+    id: int
+    pull_request_review_id: Optional[int]
+    original_position: Optional[int]
+    original_commit_id: Optional[str]
+    pull_request_url: Optional[str]
+    diff_hunk: Optional[str]
+    node_id: str
+    user: User
+    position: Optional[int]
+    line: Optional[int]
+    path: Optional[str]
+    commit_id: Optional[str]
+    created_at: str
+    updated_at: str
+    author_association: str
+    body: str
+
+    def __init__(self, payload: dict):
         self.url = payload.get("url")
         self.html_url = payload.get("html_url")
         self.issue_url = payload.get("issue_url")
@@ -250,7 +440,19 @@ class Comment:
 
 
 class ChecksApp:
-    def __init__(self, payload):
+    id: int
+    node_id: str
+    owner: User
+    name: str
+    description: str
+    external_url: str
+    html_url: str
+    created_at: str
+    updated_at: str
+    permissions: Permissions
+    events: List[str]
+
+    def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.owner = User(payload.get("owner"))
@@ -265,7 +467,13 @@ class ChecksApp:
 
 
 class ChecksPullRequest:
-    def __init__(self, payload):
+    url: str
+    id: int
+    number: int
+    head: RawDict
+    base: RawDict
+
+    def __init__(self, payload: dict):
         self.url = payload.get("url")
         self.id = payload.get("id")
         self.number = payload.get("number")
@@ -274,13 +482,29 @@ class ChecksPullRequest:
 
 
 class CommitUser:
-    def __init__(self, payload):
+    name: str
+    email: str
+    username: Optional[str]
+
+    def __init__(self, payload: dict):
         self.name = payload.get("name")
         self.email = payload.get("email")
         self.username = payload.get("username")
 
 
 class Commit:
+    id: str
+    tree_id: str
+    distinct: bool
+    message: str
+    url: str
+    timestamp: str
+    author: CommitUser
+    committer: CommitUser
+    added: List[str]
+    removed: List[str]
+    modified: List[str]
+
     def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.tree_id = payload.get("tree_id")
@@ -296,7 +520,24 @@ class Commit:
 
 
 class CheckSuite:
-    def __init__(self, payload):
+    id: int
+    node_id: str
+    head_branch: str
+    head_sha: str
+    status: str
+    conclusion: Optional[str]
+    url: str
+    before: str
+    after: str
+    pull_requests: List[ChecksPullRequest]
+    app: ChecksApp
+    created_at: str
+    updated_at: str
+    latest_check_runs_count: Optional[int]
+    check_runs_url: Optional[str]
+    head_commit: Optional[Commit]
+
+    def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.head_branch = payload.get("head_branch")
@@ -318,7 +559,13 @@ class CheckSuite:
 
 
 class CheckRunOutput:
-    def __init__(self, payload):
+    title: Optional[str]
+    summary: Optional[str]
+    text: Optional[str]
+    annotations_count: int
+    annotations_url: str
+
+    def __init__(self, payload: dict):
         self.title = payload.get("title")
         self.summary = payload.get("summary")
         self.text = payload.get("text")
@@ -327,7 +574,24 @@ class CheckRunOutput:
 
 
 class CheckRun:
-    def __init__(self, payload):
+    id: int
+    node_id: str
+    head_sha: str
+    external_id: str
+    url: str
+    html_url: str
+    details_url: str
+    status: str
+    conclusion: Optional[str]
+    started_at: str
+    completed_at: Optional[str]
+    output: CheckRunOutput
+    name: str
+    check_suite: CheckSuite
+    app: ChecksApp
+    pull_requests: List[ChecksPullRequest]
+
+    def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.head_sha = payload.get("head_sha")
@@ -348,34 +612,33 @@ class CheckRun:
         ]
 
 
-class Permissions:
-    def __init__(self, payload):
-        self.metadata = payload.get("metadata")
-        self.contents = payload.get("contents")
-        self.issues = payload.get("issues")
-        self.administration = payload.get("administration")
-        self.statuses = payload.get("statuses")
-        self.repository_projects = payload.get("repository_projects")
-        self.members = payload.get("members")
-        self.repository_hooks = payload.get("repository_hooks")
-        self.pull_requests = payload.get("pull_requests")
-        self.pull = payload.get("pull")
-        self.push = payload.get("push")
-        self.admin = payload.get("admin")
-        self.pages = payload.get("pages")
-        self.deployments = payload.get("deployments")
-        self.checks = payload.get("checks")
-        self.vulnerability_alerts = payload.get("vulnerability_alerts")
-        self.organization_administration = payload.get("organization_administration")
-        self.organization_hooks = payload.get("organization_hooks")
-        self.organization_plan = payload.get("organization_plan")
-        self.organization_projects = payload.get("organization_projects")
-        self.organization_user_blocking = payload.get("organization_user_blocking")
-        self.team_discussions = payload.get("team_discussions")
+class ShortInstallation:
+    id: int
+    node_id: str
+
+    def __init__(self, payload: dict):
+        self.id = payload.get("id")
+        self.node_id = payload.get("node_id")
 
 
 class Installation:
-    def __init__(self, payload):
+    id: int
+    node_id: Optional[str]
+    account: User
+    repository_selection: str
+    access_tokens_url: str
+    repositories_url: str
+    html_url: str
+    app_id: int
+    target_id: int
+    permissions: Optional[Permissions]
+    events: List[str]
+    created_at: int
+    updated_at: int
+    single_file_name: Optional[str]
+    target_type: str
+
+    def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.node_id = payload.get("node_id", None)
         self.account = _optional(payload, "account", User)
@@ -394,7 +657,15 @@ class Installation:
 
 
 class DeployKey:
-    def __init__(self, payload):
+    id: int
+    key: str
+    url: str
+    title: str
+    verified: bool
+    created_at: str
+    read_only: bool
+
+    def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.key = payload.get("key")
         self.url = payload.get("url")
@@ -405,7 +676,23 @@ class DeployKey:
 
 
 class Deployment:
-    def __init__(self, payload):
+    url: str
+    id: int
+    node_id: str
+    sha: str
+    ref: str
+    task: str
+    payload: RawDict
+    original_environment: str
+    environment: str
+    description: Optional[str]
+    creator: User
+    created_at: str
+    updated_at: str
+    statuses_url: str
+    repository_url: str
+
+    def __init__(self, payload: dict):
         self.url = payload.get("url")
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
@@ -424,7 +711,20 @@ class Deployment:
 
 
 class DeploymentStatus:
-    def __init__(self, payload):
+    url: str
+    id: int
+    node_id: str
+    state: str
+    creator: User
+    description: str
+    environment: str
+    target_url: str
+    created_at: str
+    updated_at: str
+    deployment_url: str
+    repository_url: str
+
+    def __init__(self, payload: dict):
         self.url = payload.get("url")
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
@@ -440,7 +740,14 @@ class DeploymentStatus:
 
 
 class Page:
-    def __init__(self, payload):
+    page_name: str
+    title: str
+    summary: str
+    action: str
+    sha: str
+    html_url: str
+
+    def __init__(self, payload: dict):
         self.page_name = payload.get("page_name")
         self.title = payload.get("title")
         self.summary = payload.get("summary")
@@ -450,7 +757,15 @@ class Page:
 
 
 class Label:
-    def __init__(self, payload):
+    id: int
+    node_id: str
+    url: str
+    name: str
+    color: str
+    description: str
+    default: bool
+
+    def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.url = payload.get("url")
@@ -461,7 +776,24 @@ class Label:
 
 
 class Milestone:
-    def __init__(self, payload):
+    url: str
+    html_url: str
+    labels_url: str
+    id: int
+    node_id: str
+    number: int
+    title: str
+    description: str
+    creator: Optional[User]
+    open_issues: int
+    closed_issues: int
+    state: str
+    created_at: str
+    updated_at: str
+    due_on: Optional[str]
+    closed_at: Optional[str]
+
+    def __init__(self, payload: dict):
         self.url = payload.get("url")
         self.html_url = payload.get("html_url")
         self.labels_url = payload.get("labels_url")
@@ -480,13 +812,31 @@ class Milestone:
         self.closed_at = payload.get("closed_at")
 
 
-class RawDict(dict):
-    def __init__(self, payload):
-        super().__init__(payload)
-
-
 class Issue:
-    def __init__(self, payload):
+    url: str
+    repository_url: str
+    comments_url: str
+    events_url: str
+    html_url: str
+    id: int
+    node_id: str
+    number: int
+    title: str
+    user: User
+    labels: List[Label]
+    state: str
+    locked: bool
+    assignee: Optional[User]
+    assignees: List[User]
+    milestone: Optional[Milestone]
+    comments: int
+    created_at: str
+    updated_at: str
+    closed_at: Optional[str]
+    author_association: str
+    body: str
+
+    def __init__(self, payload: dict):
         self._payload = payload
         self.url = payload.get("url")
         self.repository_url = payload.get("repository_url")
@@ -511,12 +861,17 @@ class Issue:
         self.author_association = payload.get("author_association")
         self.body = payload.get("body")
 
-    def labels_url(self, name: str = None):
+    def labels_url(self, name: str = None) -> str:
         return _transform(self._payload["labels_url"], locals())
 
 
 class PurchaseAccount:
-    def __init__(self, payload):
+    type: str
+    id: int
+    login: str
+    organization_billing_email: str
+
+    def __init__(self, payload: dict):
         self.type = payload.get("type")
         self.id = payload.get("id")
         self.login = payload.get("login")
@@ -524,7 +879,18 @@ class PurchaseAccount:
 
 
 class Plan:
-    def __init__(self, payload):
+    id: int
+    name: str
+    description: str
+    monthly_price_in_cents: int
+    yearly_price_in_cents: int
+    yearly_price: Optional[int]
+    price_model: str
+    has_free_trial: bool
+    unit_name: str
+    bullets: List[str]
+
+    def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.name = payload.get("name")
         self.description = payload.get("description")
@@ -537,8 +903,16 @@ class Plan:
         self.bullets = payload.get("bullets")
 
 
-class MarketplacePurcahase:
-    def __init__(self, payload):
+class MarketplacePurchase:
+    account: PurchaseAccount
+    billing_cycle: str
+    unit_count: int
+    on_free_trial: bool
+    free_trial_ends_on: Optional[str]
+    next_billing_date: str
+    plan: Plan
+
+    def __init__(self, payload: dict):
         self.account = PurchaseAccount(payload.get("account"))
         self.billing_cycle = payload.get("billing_cycle")
         self.unit_count = payload.get("unit_count")
@@ -549,7 +923,18 @@ class MarketplacePurcahase:
 
 
 class Team:
-    def __init__(self, payload):
+    name: str
+    id: int
+    node_id: str
+    slug: str
+    description: str
+    privacy: str
+    url: str
+    html_url: str
+    repositories_url: str
+    permission: str
+
+    def __init__(self, payload: dict):
         self._payload = payload
         self.name = payload.get("name")
         self.id = payload.get("id")
@@ -562,12 +947,21 @@ class Team:
         self.repositories_url = payload.get("repositories_url")
         self.permission = payload.get("permission")
 
-    def members_url(self, member: str = None):
+    def members_url(self, member: str = None) -> str:
         return _transform(self._payload["members_url"], locals())
 
 
 class Hook:
-    def __init__(self, payload):
+    type: str
+    id: int
+    name: str
+    active: bool
+    events: List[str]
+    config: RawDict
+    updated_at: str
+    created_at: str
+
+    def __init__(self, payload: dict):
         self.type = payload.get("type")
         self.id = payload.get("id")
         self.name = payload.get("name")
@@ -579,7 +973,13 @@ class Hook:
 
 
 class Membership:
-    def __init__(self, payload):
+    url: str
+    state: str
+    role: str
+    organization_url: str
+    user: User
+
+    def __init__(self, payload: dict):
         self.url = payload.get("url")
         self.state = payload.get("state")
         self.role = payload.get("role")
@@ -588,7 +988,21 @@ class Membership:
 
 
 class Asset:
-    def __init__(self, payload):
+    url: str
+    id: str
+    node_id: str
+    name: str
+    label: str
+    uploader: User
+    content_type: str
+    state: str
+    size: str
+    download_count: str
+    created_at: str
+    updated_at: str
+    browser_download_url: str
+
+    def __init__(self, payload: dict):
         self.url = payload.get("url")
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
@@ -605,7 +1019,26 @@ class Asset:
 
 
 class Release:
-    def __init__(self, payload):
+    url: str
+    assets_url: Optional[str]
+    upload_url: Optional[str]
+    html_url: str
+    id: int
+    node_id: Optional[str]
+    tag_name: str
+    target_commitish: str
+    name: str
+    draft: bool
+    author: User
+    prerelease: bool
+    created_at: str
+    published_at: Optional[str]
+    assets: List[Asset]
+    tarball_url: Optional[str]
+    zipball_url: Optional[str]
+    body: Optional[str]
+
+    def __init__(self, payload: dict):
         self.url = payload.get("url")
         self.assets_url = payload.get("assets_url", None)
         self.upload_url = payload.get("upload_url", None)
@@ -627,7 +1060,19 @@ class Release:
 
 
 class PackageFile:
-    def __init__(self, payload):
+    download_url: str
+    id: str
+    name: str
+    sha256: str
+    sha1: str
+    md5: str
+    content_type: str
+    state: str
+    size: str
+    created_at: str
+    updated_at: str
+
+    def __init__(self, payload: dict):
         self.download_url = payload.get("download_url")
         self.id = payload.get("id")
         self.name = payload.get("name")
@@ -642,7 +1087,27 @@ class PackageFile:
 
 
 class PackageVersion:
-    def __init__(self, payload):
+    id: int
+    version: str
+    summary: str
+    body: str
+    body_html: str
+    release: Release
+    manifest: str
+    html_url: str
+    tag_name: str
+    target_commitish: str
+    target_oid: str
+    draft: bool
+    prerelease: bool
+    created_at: str
+    updated_at: str
+    metadata: List[Any]
+    package_files: List[PackageFile]
+    author: User
+    installation_command: str
+
+    def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.version = payload.get("version")
         self.summary = payload.get("summary")
@@ -667,7 +1132,13 @@ class PackageVersion:
 
 
 class Registry:
-    def __init__(self, payload):
+    about_url: str
+    name: str
+    type: str
+    url: str
+    vendor: str
+
+    def __init__(self, payload: dict):
         self.about_url = payload.get("about_url")
         self.name = payload.get("name")
         self.type = payload.get("type")
@@ -676,7 +1147,17 @@ class Registry:
 
 
 class Package:
-    def __init__(self, payload):
+    id: int
+    name: str
+    package_type: str
+    html_url: str
+    created_at: str
+    updated_at: str
+    owner: User
+    package_version: PackageVersion
+    registry: Registry
+
+    def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.name = payload.get("name")
         self.package_type = payload.get("package_type")
@@ -689,7 +1170,16 @@ class Package:
 
 
 class PageBuild:
-    def __init__(self, payload):
+    url: str
+    status: str
+    error: RawDict
+    pusher: User
+    commit: str
+    duration: int
+    created_at: str
+    updated_at: str
+
+    def __init__(self, payload: dict):
         self.url = payload.get("url")
         self.status = payload.get("status")
         self.error = RawDict(payload.get("error"))
@@ -701,7 +1191,21 @@ class PageBuild:
 
 
 class ProjectCard:
-    def __init__(self, payload):
+    url: str
+    project_url: str
+    column_url: str
+    column_id: int
+    id: int
+    node_id: str
+    note: Optional[str]
+    archived: bool
+    after_id: Optional[str]
+    creator: User
+    created_at: str
+    updated_at: str
+    content_url: Optional[str]
+
+    def __init__(self, payload: dict):
         self.url = payload.get("url")
         self.project_url = payload.get("project_url")
         self.column_url = payload.get("column_url")
@@ -718,7 +1222,17 @@ class ProjectCard:
 
 
 class ProjectColumn:
-    def __init__(self, payload):
+    url: str
+    project_url: str
+    cards_url: str
+    id: int
+    node_id: str
+    name: str
+    created_at: str
+    updated_at: str
+    after_id: Optional[str]
+
+    def __init__(self, payload: dict):
         self.url = payload.get("url")
         self.project_url = payload.get("project_url")
         self.cards_url = payload.get("cards_url")
@@ -731,7 +1245,21 @@ class ProjectColumn:
 
 
 class Project:
-    def __init__(self, payload):
+    owner_url: str
+    url: str
+    html_url: str
+    columns_url: str
+    id: int
+    node_id: str
+    name: str
+    body: str
+    number: int
+    state: str
+    creator: User
+    created_at: str
+    updated_at: str
+
+    def __init__(self, payload: dict):
         self.owner_url = payload.get("owner_url")
         self.url = payload.get("url")
         self.html_url = payload.get("html_url")
@@ -748,7 +1276,13 @@ class Project:
 
 
 class Ref:
-    def __init__(self, payload):
+    label: str
+    ref: str
+    sha: str
+    user: User
+    repo: Repository
+
+    def __init__(self, payload: dict):
         self.label = payload.get("label")
         self.ref = payload.get("ref")
         self.sha = payload.get("sha")
@@ -757,7 +1291,53 @@ class Ref:
 
 
 class PullRequest:
-    def __init__(self, payload):
+    url: str
+    id: int
+    node_id: str
+    html_url: str
+    diff_url: str
+    patch_url: str
+    issue_url: str
+    number: int
+    state: str
+    locked: bool
+    title: str
+    user: User
+    body: str
+    created_at: str
+    updated_at: str
+    closed_at: Optional[str]
+    merged_at: Optional[str]
+    merge_commit_sha: Optional[str]
+    assignee: Optional[User]
+    assignees: List[User]
+    requested_reviewers: List[User]
+    requested_teams: List[str]
+    labels: List[Label]
+    milestone: Optional[str]
+    commits_url: str
+    review_comments_url: str
+    comments_url: str
+    statuses_url: str
+    head: Ref
+    base: Ref
+    _links: RawDict
+    author_association: str
+    draft: bool
+    merged: Optional[bool]
+    mergeable: Optional[bool]
+    rebaseable: Optional[bool]
+    mergeable_state: Optional[str]
+    merged_by: Optional[str]
+    comments: Optional[int]
+    review_comments: Optional[int]
+    maintainer_can_modify: Optional[bool]
+    commits: Optional[int]
+    additions: Optional[int]
+    deletions: Optional[int]
+    changed_files: Optional[int]
+
+    def __init__(self, payload: dict):
         self._payload = payload
         self.url = payload.get("url")
         self.id = payload.get("id")
@@ -807,12 +1387,24 @@ class PullRequest:
         self.deletions = payload.get("deletions")
         self.changed_files = payload.get("changed_files")
 
-    def review_comment_url(self, number: int = None):
+    def review_comment_url(self, number: int = None) -> str:
         return _transform(self._payload["review_comment_url"], locals())
 
 
 class Review:
-    def __init__(self, payload):
+    id: int
+    node_id: str
+    user: User
+    body: Optional[str]
+    commit_id: str
+    submitted_at: str
+    state: str
+    html_url: str
+    pull_request_url: str
+    author_association: str
+    _links: RawDict
+
+    def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.user = User(payload.get("user"))
@@ -827,7 +1419,14 @@ class Review:
 
 
 class VulnerabilityAlert:
-    def __init__(self, payload):
+    id: int
+    affected_range: str
+    affected_package_name: str
+    external_reference: str
+    external_identifier: str
+    fixed_in: str
+
+    def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.affected_range = payload.get("affected_range")
         self.affected_package_name = payload.get("affected_package_name")
@@ -837,18 +1436,28 @@ class VulnerabilityAlert:
 
 
 class VulnerablePackage:
-    def __init__(self, payload):
+    ecosystem: str
+    name: str
+
+    def __init__(self, payload: dict):
         self.ecosystem = payload.get("ecosystem")
         self.name = payload.get("name")
 
 
 class PackageVersionInfo:
-    def __init__(self, payload):
+    identifier: str
+
+    def __init__(self, payload: dict):
         self.identifier = payload.get("identifier")
 
 
 class Vulnerability:
-    def __init__(self, payload):
+    package: VulnerablePackage
+    severity: str
+    vulnerable_version_range: str
+    first_patched_version: PackageVersionInfo
+
+    def __init__(self, payload: dict):
         self.package = VulnerablePackage(payload.get("package"))
         self.severity = payload.get("severity")
         self.vulnerable_version_range = payload.get("vulnerable_version_range")
@@ -858,18 +1467,34 @@ class Vulnerability:
 
 
 class SecurityVulnerabilityIdentifier:
-    def __init__(self, payload):
-        self.value = payload.get("value")
-        self.type = payload.get("type")
+    value: str
+    type: str
+
+    def __init__(self, payload: dict):
+        self.value: str = payload.get("value")
+        self.type: str = payload.get("type")
 
 
 class SecurityAdvisoryReference:
-    def __init__(self, payload):
+    url: str
+
+    def __init__(self, payload: dict):
         self.url = payload.get("url")
 
 
 class SecurityAdvisory:
-    def __init__(self, payload):
+    ghsa_id: str
+    summary: str
+    description: str
+    severity: str
+    identifiers: List[SecurityVulnerabilityIdentifier]
+    references: List[SecurityAdvisoryReference]
+    published_at: str
+    updated_at: str
+    withdrawn_at: Optional[str]
+    vulnerabilities: List[Vulnerability]
+
+    def __init__(self, payload: dict):
         self.ghsa_id = payload.get("ghsa_id")
         self.summary = payload.get("summary")
         self.description = payload.get("description")
@@ -891,7 +1516,14 @@ class SecurityAdvisory:
 
 
 class SponsorshipTier:
-    def __init__(self, payload):
+    node_id: str
+    created_at: str
+    description: str
+    monthly_price_in_cents: int
+    monthly_price_in_dollars: int
+    name: str
+
+    def __init__(self, payload: dict):
         self.node_id = payload.get("node_id")
         self.created_at = payload.get("created_at")
         self.description = payload.get("description")
@@ -901,7 +1533,14 @@ class SponsorshipTier:
 
 
 class Sponsorship:
-    def __init__(self, payload):
+    node_id: str
+    created_at: str
+    maintainer: User
+    sponsor: User
+    privacy_level: str
+    tier: SponsorshipTier
+
+    def __init__(self, payload: dict):
         self.node_id = payload.get("node_id")
         self.created_at = payload.get("created_at")
         self.maintainer = User(payload.get("maintainer"))
@@ -911,21 +1550,34 @@ class Sponsorship:
 
 
 class StatusBranchCommit:
-    def __init__(self, payload):
+    sha: str
+    url: str
+    html_url: Optional[str]
+
+    def __init__(self, payload: dict):
         self.sha = payload.get("sha")
         self.url = payload.get("url")
         self.html_url = payload.get("html_url", None)
 
 
 class Branch:
-    def __init__(self, payload):
+    name: str
+    commit: StatusBranchCommit
+    protected: str
+
+    def __init__(self, payload: dict):
         self.name = payload.get("name")
         self.commit = StatusBranchCommit(payload.get("commit"))
         self.protected = payload.get("protected")
 
 
 class StatusCommitVerification:
-    def __init__(self, payload):
+    verified: bool
+    reason: str
+    signature: str
+    payload: str
+
+    def __init__(self, payload: dict):
         self.verified = payload.get("verified")
         self.reason = payload.get("reason")
         self.signature = payload.get("signature")
@@ -933,14 +1585,26 @@ class StatusCommitVerification:
 
 
 class StatusNestedCommitUser:
-    def __init__(self, payload):
+    name: str
+    email: str
+    date: str
+
+    def __init__(self, payload: dict):
         self.name = payload.get("name")
         self.email = payload.get("email")
         self.date = payload.get("date")
 
 
 class StatusNestedCommit:
-    def __init__(self, payload):
+    author: StatusNestedCommitUser
+    committer: StatusNestedCommitUser
+    message: str
+    tree: StatusBranchCommit
+    url: str
+    comment_count: int
+    verification: StatusCommitVerification
+
+    def __init__(self, payload: dict):
         self.author = StatusNestedCommitUser(payload.get("author"))
         self.committer = StatusNestedCommitUser(payload.get("committer"))
         self.message = payload.get("message")
@@ -951,7 +1615,17 @@ class StatusNestedCommit:
 
 
 class StatusCommit:
-    def __init__(self, payload):
+    sha: str
+    node_id: str
+    commit: StatusNestedCommit
+    url: str
+    html_url: str
+    comments_url: str
+    author: Optional[User]
+    committer: Optional[User]
+    parents: List[StatusBranchCommit]
+
+    def __init__(self, payload: dict):
         self.sha = payload.get("sha")
         self.node_id = payload.get("node_id")
         self.commit = StatusNestedCommit(payload.get("commit"))
@@ -964,7 +1638,11 @@ class StatusCommit:
 
 
 class ContentReference:
-    def __init__(self, payload):
+    id: int
+    node_id: str
+    reference: str
+
+    def __init__(self, payload: dict):
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.reference = payload.get("reference")
